;; Generated package description from .el  -*- dracula-themeno-byte-compile: t -*-
(define-package "dracula-theme" "1.8.2.0.20250407.120528" "Dracula Theme" '((emacs "24.3")) :commit "8b3a005db9e8b7ac57e683bc6631cdc7643e8150" :maintainer '("tienne Deparis" . "etienne@depar.is") :url "https://github.com/dracula/emacs")
